define([
  './navigation/navigationService',
  './requestService/requestService',
  './splunkStoreService/splunkStoreService',
  './filterService/filterService',
  './apiIndexStorageService/apiIndexStorageService',
  './api-manager/apiMgrService',
  './dataService/dataService',
  './rules/rulesDescription',
  './tableFilterService/tableFilterService',
  './key-equivalence/keyEquivalenceService',
  './currentDataService/currentDataService',
  './beautifier/beautifier-json',
  './reporting/reportingService',
  './vis2png/vis2png',
  './notificationService/notificationService',
  './csv-request/csvRequestService',
  './xml-beautifier/xml-beautifier',
  './get-ids/getIdService',
  './token-model/urlTokenModelService',
  './group-handler/group-handler',
  './date-diff/dateDiffService',
  './file-editor/file-editor',
  './cdb-editor/cdb-editor',
  './restartService/restartService',
  './checkDaemons/checkDaemonsService',
  './app-version/appVersionService',
  './sourceTypeStorageService/sourceTypeStorageService',
  './splunk-services/splunk-users',
  './validationService/validationService',
  './requirementService/requirementService',
  './security_services/actions_enum',
  './security_services/security_service',
  './security/rule/ruleService',
  './security/role/roleService',
  './security/policy/policyService',
  './security/user/userService',
], function () {})
